{% extends 'leprikon/base.html' %}
{% load i18n cms_tags leprikon_tags %}

{% block content %}

<h1>{% block title %}{% trans 'Summary' %}{% endblock %}</h1>

{% static_placeholder "summary" %}

{% if payment_status.price > 0 %}
<h2>{% blocktrans with school_year=request.school_year %}Payment status for school year {{ school_year }}{% endblocktrans %}</h2>
<p>
    <a href="{% url 'leprikon:registration_list' %}"><strong style="color: {{ payment_status.color }}">{{ payment_status.title }}</strong></a>
    ({% trans 'total price of all registrations' %}: {{ payment_status.price | currency }},
    {% trans 'discounts' %}: {{ payment_status.discount | currency }},
    {% trans 'paid' %}: {{ payment_status.paid | currency }})
</p>
{% endif %}

{% if new_messages.count %}
<h2>{% trans 'New messages' %}</h2>
{% include 'leprikon/messages_table.html' with object_list=new_messages %}
{% endif %}

{% endblock %}
